outer.buffered: Create a buffered habitat around a set of points.

View source: R/utils.R

outer.bufferedR Documentation

Create a buffered habitat around a set of points.

Description

Creates a polygon a certain distance from each of a set of points. It is used for creating a default habitat outline for eems().

Usage

outer.buffered(coords, d = NULL)

Arguments

coords

A two-column matrix of point coordinates (longitude, latitude).

d

Rough buffer distance. Not necessarily kept completely to keep the polygon simple. Defaults to 0.2 of the length of the hull of the coords.

Value

A two-column matrix of coordinates with the outer boundary points of the containing polygon.

Examples

#  Create a buffer around the example habitat
outer <- outer.buffered(ex.coords)

reems documentation built on May 6, 2026, 1:07 a.m.