reems-package: Estimating Effective Migration Surfaces (EEMS)

reemsR Documentation

Estimating Effective Migration Surfaces (EEMS)

Description

Provides several functions to run EEMS analyses and to visualise the results of EEMS. For an exmplanation of and introduction to the EEMS method, see Petkova, D., Novembre, J. & Stephens, M. (2016) <doi:10.1038/ng.3464>.

eems is the main entrypoint, running EEMS analyses on single nucleotide polymorphism data allele frequeny available as R matrices.

eems.from.files runs an EEMS analysis from input data available as tabular files, and correesponds precisely to the original EEMS utility available at <https://github.com/dipetkov/eems>.

eems.plots takes the output of one or more EEMS runs and produces contour plots of the effective migration and diversity rates, as well as scatterplots of observed vs fitted genetic dissimilarities and trace plots to assess convergence.

eems.population.grid plots the population grid, with all edges in the same color, to visualize the grid before estimating migration and diversity rates.

eems.voronoi.samples and eems.posterior.draws both take random samples from the posterior distribution of the migration and diversity rates and plot them to visualize the posterior variance (in a slightly different way).


reems documentation built on May 6, 2026, 1:07 a.m.