| outer.buffered | R Documentation |
Creates a polygon a certain distance from each of a set of points.
It is used for creating a default habitat outline for eems().
outer.buffered(coords, d = NULL)
coords |
A two-column matrix of point coordinates (longitude, latitude). |
d |
Rough buffer distance. Not necessarily kept completely to keep the polygon simple.
Defaults to 0.2 of the length of the hull of the |
A two-column matrix of coordinates with the outer boundary points of the containing polygon.
# Create a buffer around the example habitat
outer <- outer.buffered(ex.coords)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.